==> nextcloud-19.0.4.tgz: nextcloud/apps/comments/l10n/it.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commenti",
    "You commented" : "Hai commentato",
    "%1$s commented" : "%1$s ha commentato",
    "{author} commented" : "{author} ha commentato",
    "You commented on %1$s" : "Hai commentato su %1$s",
    "You commented on {file}" : "Hai commentato su {file}",
    "%1$s commented on %2$s" : "%1$s ha commentato %2$s",
    "{author} commented on {file}" : "{author} ha commentato su {file}",
    "<strong>Comments</strong> for files" : "<strong>Commenti</strong> sui file",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sei stato menzionato su \"{file}\", in un commento di un utente che è stato eliminato",
    "{user} mentioned you in a comment on “{file}”" : "{user} ti ha menzionato in un commento su \"{file}\".",
    "Files app plugin to add comments to files" : "Estensione dell'applicazione File per aggiungere commenti ai file",
    "Edit comment" : "Modifica commento",
    "Delete comment" : "Elimina commento",
    "New comment …" : "Nuovo commento...",
    "Post" : "Commento",
    "Cancel" : "Annulla",
    "[Deleted user]" : "[Utente eliminato]",
    "No comments yet, start the conversation!" : "Ancora nessun commento, inizia la conversazione!",
    "More comments …" : "Altri commenti...",
    "Save" : "Salva",
    "Allowed characters {count} of {max}" : "Caratteri consentiti {count} di {max}",
    "Error occurred while retrieving comment with ID {id}" : "Si è verificato un errore durante il recupero del commento con ID {id}",
    "Error occurred while updating comment with id {id}" : "Si è verificato un errore durante il tentativo di aggiornamento del commento con id {id}",
    "Error occurred while posting comment" : "Si è verificato un errore durante la pubblicazione del commento.",
    "_%n unread comment_::_%n unread comments_" : ["%n commento non letto","%n commenti non letti"],
    "_1 new comment_::_{unread} new comments_" : ["1 nuovo commento","{unread} nuovi commenti"],
    "Comment" : "Commento"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.2.tgz: nextcloud/apps/comments/l10n/it.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commenti",
    "You commented" : "Hai commentato",
    "%1$s commented" : "%1$s ha commentato",
    "{author} commented" : "{author} ha commentato",
    "You commented on %1$s" : "Hai commentato su %1$s",
    "You commented on {file}" : "Hai commentato su {file}",
    "%1$s commented on %2$s" : "%1$s ha commentato %2$s",
    "{author} commented on {file}" : "{author} ha commentato su {file}",
    "<strong>Comments</strong> for files" : "<strong>Commenti</strong> sui file",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sei stato menzionato su \"{file}\", in un commento di un utente che è stato eliminato",
    "{user} mentioned you in a comment on “{file}”" : "{user} ti ha menzionato in un commento su \"{file}\".",
    "Files app plugin to add comments to files" : "Estensione dell'applicazione File per aggiungere commenti ai file",
    "Edit comment" : "Modifica commento",
    "Delete comment" : "Elimina commento",
    "Cancel edit" : "Annulla modifica",
    "Post comment" : "Pubblica commento",
    "No comments yet, start the conversation!" : "Ancora nessun commento, inizia la conversazione!",
    "No more messages" : "Non ci sono altri messaggi",
    "Retry" : "Riprova",
    "Unable to load the comments list" : "Impossibile caricare l'elenco dei commenti",
    "_%n unread comment_::_%n unread comments_" : ["%n commento non letto","%n commenti non letti"],
    "_1 new comment_::_{unread} new comments_" : ["1 nuovo commento","{unread} nuovi commenti"],
    "Comment" : "Commento",
    "An error occurred while trying to edit the comment" : "Si è verificato un errore durante il tentativo di modificare il commento",
    "Comment deleted" : "Commento eliminato",
    "An error occurred while trying to delete the comment" : "Si è verificato un errore durante il tentativo di eliminare il commento",
    "An error occurred while trying to create the comment" : "Si è verificato un errore durante il tentativo di creare il commento",
    "New comment …" : "Nuovo commento...",
    "Post" : "Commento",
    "Cancel" : "Annulla",
    "[Deleted user]" : "[Utente eliminato]",
    "More comments …" : "Altri commenti...",
    "Save" : "Salva",
    "Allowed characters {count} of {max}" : "Caratteri consentiti {count} di {max}",
    "Error occurred while retrieving comment with ID {id}" : "Si è verificato un errore durante il recupero del commento con ID {id}",
    "Error occurred while updating comment with id {id}" : "Si è verificato un errore durante il tentativo di aggiornamento del commento con id {id}",
    "Error occurred while posting comment" : "Si è verificato un errore durante la pubblicazione del commento."
},
"nplurals=2; plural=(n != 1);");
